pub struct Dag { /* private fields */ }Expand description
Represents DAG of stages.
Implementations
sourceimpl Dag
impl Dag
sourcepub fn add_initial_data(&mut self, stage_id: usize, initial_data: u64)
pub fn add_initial_data(&mut self, stage_id: usize, initial_data: u64)
Adds initial data for a stage.
sourcepub fn initial_data(&self) -> &BTreeMap<usize, u64>
pub fn initial_data(&self) -> &BTreeMap<usize, u64>
Returns map of initial data sizes for each stage.
sourcepub fn add_stage(
&mut self,
tasks: Vec<Box<dyn Task>>,
upload_result_to_dfs: bool
) -> usize
pub fn add_stage( &mut self, tasks: Vec<Box<dyn Task>>, upload_result_to_dfs: bool ) -> usize
Add new stage.
sourcepub fn add_connection(
&mut self,
from: usize,
to: usize,
shuffle: Option<Box<dyn Shuffle>>
) -> usize
pub fn add_connection( &mut self, from: usize, to: usize, shuffle: Option<Box<dyn Shuffle>> ) -> usize
Add new connection between stages.
sourcepub fn mark_started(&mut self, stage_id: usize)
pub fn mark_started(&mut self, stage_id: usize)
Mark stage as started.
sourcepub fn mark_completed(&mut self, stage_id: usize)
pub fn mark_completed(&mut self, stage_id: usize)
Mark stage as completed.
sourcepub fn ready_stages(&self) -> &BTreeSet<usize>
pub fn ready_stages(&self) -> &BTreeSet<usize>
Returns set of all stage ready to be started.
sourcepub fn running_stages(&self) -> &BTreeSet<usize>
pub fn running_stages(&self) -> &BTreeSet<usize>
Returns set of all running stage.
sourcepub fn completed_stages(&self) -> &BTreeSet<usize>
pub fn completed_stages(&self) -> &BTreeSet<usize>
Returns set of all completed stage.
sourcepub fn connection(&self, connection_id: usize) -> &Connection
pub fn connection(&self, connection_id: usize) -> &Connection
Returns connection by id.
sourcepub fn stage_dependencies(&self, stage_id: usize) -> &Vec<Connection>
pub fn stage_dependencies(&self, stage_id: usize) -> &Vec<Connection>
Returns stage dependencies.
sourcepub fn outgoing_connections(&self, stage_id: usize) -> &Vec<usize>
pub fn outgoing_connections(&self, stage_id: usize) -> &Vec<usize>
Returns stage outdoing connections.