Struct dslab_mr::dag::SimpleTask
source · pub struct SimpleTask {
pub id: u64,
pub cores: u32,
pub memory: u64,
pub flops_per_byte: f64,
pub output_size_ratio: f64,
}Expand description
Simple task which implements Task trait.
Fields
id: u64Id of the task.
cores: u32Number of cores needed for a task.
memory: u64Amount of memory needed for a task.
flops_per_byte: f64Needed flops ber each byte of input data, used to implement Task::flops.
output_size_ratio: f64Ratio of output size to input size, used to implement Task::output_size.
Implementations