pub trait Task {
// Required methods
fn id(&self) -> u64;
fn cores(&self) -> u32;
fn memory(&self) -> u64;
fn flops(&self, input_size: u64) -> f64;
fn output_size(&self, input_size: u64) -> u64;
}Expand description
Trait for a task.
Required Methods
sourcefn flops(&self, input_size: u64) -> f64
fn flops(&self, input_size: u64) -> f64
Computational complexity of a task given size of input data.
sourcefn output_size(&self, input_size: u64) -> u64
fn output_size(&self, input_size: u64) -> u64
Size of the output data of a task given size of input data.