pub struct Experiment { /* private fields */ }
Helper struct for running multiple experiments.

Implementations

source

impl Experiment

source

pub fn new( seed: u64, plans: Vec<Plan>, systems: Vec<(String, SystemConfig)>, replication_strategies: Vec<String>, placement_strategies: Vec<String>, replication_strategy_resolver: fn(_: &str) -> Box<dyn ReplicationStrategy>, placement_strategy_resolver: fn(_: &str) -> Box<dyn DynamicPlacementStrategy>, traces_folder: Option<PathBuf> ) -> Self

Creates new experiment. There will be one simulation run for each combination of replication strategy, placement strategy, plan, system.

  • seed — seed for each simulation.
  • plans — simulation plans.
  • systems — system configs along with their names.
  • replication_strategies — names of replication strategies.
  • placement_strategies — names of placement strategies.
  • replication_strategy_resolver — function to convert a string from replication_strategies to [ReplicationStrategy].
  • placement_strategy_resolver — function to convert a string from placement_strategies to DynamicPlacementStrategy.
  • traces_folder — optional folder to save traces of all simulations to.
source

pub fn run(self, threads: usize) -> Vec<RunResult>

Run all simulations using given number of threads and collect results.