pub fn collect_all_input(
    input: &[DataItem],
    dfs: &DistributedFileSystem
) -> Vec<(DataItem, Vec<Id>)>
Helper function to collect all inputs along with the location of each one.

  • DataItem::Replicated is split into individual chunks.
  • DataItem::Local is split into parts with the size of chunk_size except at most one.
  • DataItem::Chunk remains unchanged.