pub struct RunStats {
Show 14 fields pub total_makespan: f64, pub total_dag_count: usize, pub completed_dag_count: usize, pub average_dag_makespan: f64, pub min_dag_makespan: f64, pub max_dag_makespan: f64, pub total_cpu_flops: f64, pub cpu_utilization: f64, pub memory_utilization: f64, pub total_network_traffic: f64, pub network_traffic_between_racks: f64, pub network_traffic_between_hosts: f64, pub total_chunks_in_dfs: u64, pub total_space_used: f64, /* private fields */
}
Some stats from a completed simulation.

Fields

total_makespan: f64

Total time between first NewDag event and last simulation event.

total_dag_count: usize

Total number of received DAGs.

completed_dag_count: usize

Total number of completed DAGs.

average_dag_makespan: f64

Average makespan of a DAG among completed DAGs.

min_dag_makespan: f64

Minimum makespan of a DAG among completed DAGs.

max_dag_makespan: f64

Maximum makespan of a DAG among completed DAGs.

total_cpu_flops: f64

Total CPU flops used by all completed tasks.

cpu_utilization: f64

Average CPU utilization during simulation.

memory_utilization: f64

Average memory utilization during simulation.

total_network_traffic: f64

Total network traffic. Includes transfers with src == dst.

network_traffic_between_racks: f64

Total network traffic between different racks.

network_traffic_between_hosts: f64

Total network traffic between different hosts.

total_chunks_in_dfs: u64

Total number chunks in DFS in the end of the simulation.

total_space_used: f64

Fraction of the used space in the end of the simulation.

Implementations

source

impl RunStats

source

pub fn new(total_cores: u32, total_memory: u64) -> Self

Initialize new stats for a system with given number of cores and amount of memory.

source

pub fn register_dag(&mut self, makespan: f64)

Register completed DAG with given makespan.

source

pub fn register_transfer( &mut self, size: f64, src: (Id, usize), dst: (Id, usize) )

Register completed transfer with given parameters.

  • size — size of the data which was transfered.
  • src, dst — pairs (simulation component, rack) for transfer source and destination.
source

pub fn register_task_execution(&mut self, flops: f64)

Register task with a given computation size.

source

pub fn register_cpu_utilization(&mut self, cpu_utilization: f64)

Register CPU utilization measure in (number of cores used) * (time of the usage).

source

pub fn register_memory_utilization(&mut self, memory_utilization: f64)

Register memory utilization measure in (amount of memory used) * (time of the usage).

source

pub fn finalize(&mut self, makespan: f64)

Finalize result given total_makespan;