Enum dslab_mr::trace::TraceEvent
source · pub enum TraceEvent {
TaskReady {
time: f64,
dag_id: usize,
stage_id: usize,
task_id: usize,
},
TaskInQueue {
time: f64,
dag_id: usize,
stage_id: usize,
task_id: usize,
host: String,
},
TaskAssigned {
time: f64,
dag_id: usize,
stage_id: usize,
task_id: usize,
host: String,
},
TaskStarted {
time: f64,
dag_id: usize,
stage_id: usize,
task_id: usize,
cores: u32,
memory: u64,
host: String,
},
TaskCompleted {
time: f64,
dag_id: usize,
stage_id: usize,
task_id: usize,
},
DagStarted {
time: f64,
dag_id: usize,
},
DagCompleted {
time: f64,
dag_id: usize,
},
}Expand description
One trace event in a simulation.
Variants
TaskReady
Fields
Task stage is ready.
TaskInQueue
Fields
Task is waiting in a queue of a specific host for enough resources to start.
TaskAssigned
Fields
Task is assigned to a host and waits for input data to be transfered.
TaskStarted
Fields
Task started processing input.
TaskCompleted
Fields
Task finished processing input.
DagStarted
Dag received by Runner.
DagCompleted
Dag completed.
Implementations