pub struct PackingScheduler { /* private fields */ }Expand description
Implementation of a packing scheduler.
It first splits all input data uniformly among all tasks while trying to group them by host.
Then it puts all tasks in a queue and when there is at least one host with enough resources to run next task
it chooses the best host according to scalar product of resource needs for a task and available resources on a host,
multiplied by locality score. Locality score is 1 when all input is on the target host,
other_host_input_penalty if all the data is on the same rack, and other_host_input_penalty * other_rack_input_penalty
if some inputs are on a different rack.
Implementations