pub struct RunStats {Show 14 fields
pub total_makespan: f64,
pub total_dag_count: usize,
pub completed_dag_count: usize,
pub average_dag_makespan: f64,
pub min_dag_makespan: f64,
pub max_dag_makespan: f64,
pub total_cpu_flops: f64,
pub cpu_utilization: f64,
pub memory_utilization: f64,
pub total_network_traffic: f64,
pub network_traffic_between_racks: f64,
pub network_traffic_between_hosts: f64,
pub total_chunks_in_dfs: u64,
pub total_space_used: f64,
/* private fields */
}Expand description
Some stats from a completed simulation.
Fields
total_makespan: f64Total time between first NewDag event and last simulation event.
total_dag_count: usizeTotal number of received DAGs.
completed_dag_count: usizeTotal number of completed DAGs.
average_dag_makespan: f64Average makespan of a DAG among completed DAGs.
min_dag_makespan: f64Minimum makespan of a DAG among completed DAGs.
max_dag_makespan: f64Maximum makespan of a DAG among completed DAGs.
total_cpu_flops: f64Total CPU flops used by all completed tasks.
cpu_utilization: f64Average CPU utilization during simulation.
memory_utilization: f64Average memory utilization during simulation.
total_network_traffic: f64Total network traffic. Includes transfers with src == dst.
network_traffic_between_racks: f64Total network traffic between different racks.
network_traffic_between_hosts: f64Total network traffic between different hosts.
total_chunks_in_dfs: u64Total number chunks in DFS in the end of the simulation.
total_space_used: f64Fraction of the used space in the end of the simulation.
Implementations
sourceimpl RunStats
impl RunStats
sourcepub fn new(total_cores: u32, total_memory: u64) -> Self
pub fn new(total_cores: u32, total_memory: u64) -> Self
Initialize new stats for a system with given number of cores and amount of memory.
sourcepub fn register_dag(&mut self, makespan: f64)
pub fn register_dag(&mut self, makespan: f64)
Register completed DAG with given makespan.
sourcepub fn register_transfer(
&mut self,
size: f64,
src: (Id, usize),
dst: (Id, usize)
)
pub fn register_transfer( &mut self, size: f64, src: (Id, usize), dst: (Id, usize) )
Register completed transfer with given parameters.
size— size of the data which was transfered.src,dst— pairs (simulation component, rack) for transfer source and destination.
sourcepub fn register_task_execution(&mut self, flops: f64)
pub fn register_task_execution(&mut self, flops: f64)
Register task with a given computation size.
sourcepub fn register_cpu_utilization(&mut self, cpu_utilization: f64)
pub fn register_cpu_utilization(&mut self, cpu_utilization: f64)
Register CPU utilization measure in (number of cores used) * (time of the usage).
sourcepub fn register_memory_utilization(&mut self, memory_utilization: f64)
pub fn register_memory_utilization(&mut self, memory_utilization: f64)
Register memory utilization measure in (amount of memory used) * (time of the usage).
sourcepub fn finalize(&mut self, makespan: f64)
pub fn finalize(&mut self, makespan: f64)
Finalize result given total_makespan;